.. _main:

############
Pytest CMake
############

Discover and run Python tests for :term:`Pytest` with :term:`CMake`.

.. toctree::
    :maxdepth: 1

    introduction
    installing
    integration
    tutorial
    api_reference
    environment_variables
    release/index
    Source Code @ GitHub <https://github.com/python-cmake/pytest-cmake>
    glossary
